@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: admin.py 11103 2018-06-13 14:19:09Z Lavender $
+# $Id: admin.py 11117 2018-06-24 06:01:54Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2018-06-13 22:19:09 +0800 (週三, 13 六月 2018) $
-# $Revision: 11103 $
+# $Date: 2018-06-24 14:01:54 +0800 (週日, 24 六月 2018) $
+# $Revision: 11117 $
 
 import urllib
 import re
@@ -25,10 +25,27 @@ from django.conf import settings
 from django.utils.translation import ugettext_lazy as _
 from aldryn_newsblog.admin import ArticleAdmin, ArticleAdminForm
 from aldryn_newsblog.models import Article
+from aldryn_categories.admin import CategoryAdmin
+from aldryn_categories.models import Category
 from djangocms_text_ckeditor.models import Text
+from taggit import models
 
 from Zephyrus.blog_extension import views
+from Zephyrus.blog_extension.Slugify import Slugify
 
+# TAG
+slugifyUnicode = Slugify(translate=None)
+models.default_slugify = Slugify(translate=None)
+
+def slugify(self, tag, i=None):
+    slug = models.default_slugify(tag)
+    if i is not None:
+        slug += "_%d" % i
+    return slug
+
+models.TagBase.slugify = slugify
+
+# Article
 class ArticleAdminForm2(ArticleAdminForm):
     slug2 = forms.CharField(
         label=_('slug'),
@@ -129,3 +146,29 @@ class ArticleAdmin2(ArticleAdmin):
 
 admin.site.unregister(Article)
 admin.site.register(Article, ArticleAdmin2)
+
+# Category
+class CategoryAdmin2(CategoryAdmin):
+
+    def response_add(self, request, obj, post_url_continue=None):
+        slug = request.POST.get('name')
+        if slug:
+            obj.slug = slug
+        else:
+            obj.slug = obj.name
+        obj.save()
+        return super(CategoryAdmin2, self).response_add(
+            request, obj, post_url_continue=None)
+
+    def response_change(self, request, obj):
+        slug = request.POST.get('name')
+        if slug:
+            obj.slug = slug
+        else:
+            obj.slug = obj.name
+        obj.save()
+        return super(CategoryAdmin2, self).response_change(request, obj)
+
+admin.site.unregister(Category)
+admin.site.register(Category, CategoryAdmin2)
+
