@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: fix_template.py 10994 2018-04-29 07:35:56Z Lavender $
+# $Id: fix_template.py 11011 2018-05-06 04:26:57Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,12 +12,13 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2018-04-29 15:35:56 +0800 (週日, 29 四月 2018) $
-# $Revision: 10994 $
+# $Date: 2018-05-06 12:26:57 +0800 (週日, 06 五月 2018) $
+# $Revision: 11011 $
 
 import os
 import hashlib
 import traceback
+import shutil
 
 from django.core.management.base import BaseCommand
 
@@ -64,13 +65,12 @@ class Command(BaseCommand):
                     text = text.replace("{% render_block 'css' %}", cssHash)
                     text = text.replace("{% render_block 'js' %}", jsHash)
                     text = text.replace("{% cms_toolbar %}", toolbarHash)
+
+                index = htmlfile.index('.html')
+                fileBackupName = htmlfile[:index] + '_content.html'
+                shutil.copyfile(htmlfile, fileBackupName)
                     
-                if options['overwrite']:
-                    fileName = htmlfile
-                else:
-                    index = htmlfile.index('.html')
-                    fileName = htmlfile[:index] + '_user.html'
-                    
+                fileName = htmlfile           
             
                 with open(fileName, 'w') as f:
                     f.write(text)
