@@ -14,3 +14,16 @@
 # $Author: Lavender $ (last)
 # $Date: 2018-04-16 16:14:06 +0800 (週一, 16 四月 2018) $
 # $Revision: 10982 $
+
+import os
+
+from django.conf import settings
+
+STATIC_DIR = os.path.join(settings.BASE_DIR, "static")
+TEMPLATE_DIR = settings.TEMPLATES[0]['DIRS'][0]
+
+BACKUP_FILE_DIR = os.path.join(
+    STATIC_DIR, 'TemplateEditorBackup')
+
+if not os.path.isdir(BACKUP_FILE_DIR):
+    os.mkdir(BACKUP_FILE_DIR)
